@@ -1,4 +1,4 @@
-from acido.azure_utils.ManagedIdentity import ManagedAuthentication, Resources
+from acido.azure_utils.ManagedIdentity import ManagedAuthentication
 from acido.utils.decoration import __version__
 from azure.mgmt.containerinstance import ContainerInstanceManagementClient
 from azure.mgmt.containerinstance.models import (
@@ -7,7 +7,7 @@ from azure.mgmt.containerinstance.models import (
     ResourceIdentityType)
 from azure.mgmt.containerinstance.models import ContainerGroupIdentity, UserAssignedIdentities
 from azure.core.exceptions import HttpResponseError, ResourceNotFoundError
-from huepy import good, bad, info
+from huepy import bad
 
 
 from shlex import quote
@@ -22,7 +22,7 @@ logger.disabled = True
 class InstanceManager(ManagedAuthentication):
     def __init__(self, resource_group, login: bool = True, user_assigned: dict = {}, network_profile=None):
         if login:
-            credential = self.get_credential(Resources.INSTANCE)
+            credential = self.get_credential()
             subscription = self.extract_subscription(credential)
             self._client = ContainerInstanceManagementClient(
                 credential,
@@ -162,7 +162,7 @@ class InstanceManager(ManagedAuthentication):
                 identity=ContainerGroupIdentity(
                     type=ResourceIdentityType.user_assigned,
                     user_assigned_identities={
-                        self.user_assigned['id']: UserAssignedIdentities(client_id=self.user_assigned['clientId'])
+                        self.user_assigned['id']: UserAssignedIdentities(client_id=self.user_assigned.get('clientId', ''))
                     }
                 )
             )
@@ -260,3 +260,28 @@ class InstanceManager(ManagedAuthentication):
                 # We don't know what is happening, maybe transitioning?
                 print(str(e))
         return True
+
+    def get_container_logs(self, container_group_name: str, container_name: str, tail: int = None, timestamps: bool = False) -> str:
+        """
+        Retrieve logs from a container using Azure SDK.
+        
+        Args:
+            container_group_name: Name of the container group
+            container_name: Name of the container within the group
+            tail: Optional number of lines to return from the end of logs
+            timestamps: Whether to include timestamps in the logs
+            
+        Returns:
+            str: Container logs as a string
+            
+        Raises:
+            HttpResponseError: If there's an error retrieving logs
+        """
+        logs = self._client.containers.list_logs(
+            resource_group_name=self.resource_group,
+            container_group_name=container_group_name,
+            container_name=container_name,
+            tail=tail,
+            timestamps=timestamps
+        )
+        return logs.content
