@@ -9,7 +9,7 @@ from azure.mgmt.network.models import ContainerNetworkInterfaceConfiguration, IP
 from azure.mgmt.storage import StorageManagementClient
 from acido.azure_utils.ManagedIdentity import ManagedAuthentication
 from acido.azure_utils.BlobManager import BlobManager
-from acido.azure_utils.InstanceManager import InstanceManager, Resources
+from acido.azure_utils.InstanceManager import InstanceManager
 from acido.azure_utils.NetworkManager import NetworkManager, NetworkProfile
 from acido.utils.functions import chunks, jpath, expanduser, split_file
 from acido.utils.lambda_safe_pool import ThreadPoolShim
@@ -31,7 +31,7 @@ ACIDO_CREATE_STEPS = 5  # Number of steps in create_acido_image process
 
 parser = argparse.ArgumentParser()
 
-# Add subparsers for 'create' subcommand
+# Add subparsers for Docker-like subcommands
 subparsers = parser.add_subparsers(dest='subcommand', help='Subcommands')
 
 # Create subcommand
@@ -42,14 +42,45 @@ create_parser.add_argument('--image', dest='base_image_url', help='Full Docker i
 # Configure subcommand (alias for -c/--config)
 configure_parser = subparsers.add_parser('configure', help='Configure acido (alias for -c/--config)')
 
-# Regular arguments
+# Fleet subcommand (Docker-like syntax)
+fleet_parser = subparsers.add_parser('fleet', help='Create and manage fleet of containers')
+fleet_parser.add_argument('fleet_name', help='Fleet name')
+fleet_parser.add_argument('-n', '--num-instances', dest='num_instances', type=int, default=1, help='Number of instances')
+fleet_parser.add_argument('-im', '--image', dest='image_name', default='ubuntu', help='Image name')
+fleet_parser.add_argument('-t', '--task', dest='task', help='Command to execute')
+fleet_parser.add_argument('-i', '--input-file', dest='input_file', help='Input file for task')
+fleet_parser.add_argument('-w', '--wait', dest='wait', type=int, help='Max timeout')
+fleet_parser.add_argument('-o', '--output', dest='write_to_file', help='Save output to file')
+fleet_parser.add_argument('--format', dest='output_format', choices=['txt', 'json'], default='txt', help='Output format')
+fleet_parser.add_argument('-q', '--quiet', dest='quiet', action='store_true', help='Quiet mode')
+fleet_parser.add_argument('--rm-when-done', dest='rm_when_done', action='store_true', help='Remove after completion')
+
+# List subcommand (Docker-like: acido ls)
+ls_parser = subparsers.add_parser('ls', help='List all container instances')
+
+# Remove subcommand (Docker-like: acido rm)
+rm_parser = subparsers.add_parser('rm', help='Remove container instances')
+rm_parser.add_argument('name', help='Container group name or pattern to remove')
+
+# Select subcommand
+select_parser = subparsers.add_parser('select', help='Select instances by name/regex')
+select_parser.add_argument('pattern', help='Name or regex pattern to select')
+
+# Exec subcommand
+exec_parser = subparsers.add_parser('exec', help='Execute command on selected instances')
+exec_parser.add_argument('command', help='Command to execute')
+exec_parser.add_argument('-i', '--input-file', dest='input_file', help='Input file')
+exec_parser.add_argument('-o', '--output', dest='write_to_file', help='Output file')
+exec_parser.add_argument('-w', '--wait', dest='wait', type=int, default=60, help='Max retries')
+
+# Regular arguments (for backward compatibility)
 parser.add_argument("-c", "--config",
                     dest="config",
                     help="Start configuration of acido.",
                     action='store_true')
 parser.add_argument("-f", "--fleet",
                     dest="fleet",
-                    help="Create new fleet.",
+                    help="Create new fleet (deprecated: use 'acido fleet' subcommand).",
                     action='store')
 parser.add_argument("-im", "--image",
                     dest="image_name",
@@ -97,11 +128,11 @@ parser.add_argument("-s", "--select",
                     action='store')
 parser.add_argument("-l", "--list",
                     dest="list_instances",
-                    help="List all instances.",
+                    help="List all instances (deprecated: use 'acido ls').",
                     action='store_true')
 parser.add_argument("-r", "--rm",
                     dest="remove",
-                    help="Remove instances matching name/regex.",
+                    help="Remove instances matching name/regex (deprecated: use 'acido rm').",
                     action='store')
 parser.add_argument("-in", "--interactive",
                     dest="interactive",
@@ -151,6 +182,30 @@ if args.subcommand == 'create':
 if args.subcommand == 'configure':
     args.config = True
 
+# Handle 'fleet' subcommand - map to old-style flags
+if args.subcommand == 'fleet':
+    if not hasattr(args, 'fleet') or not args.fleet:
+        args.fleet = args.fleet_name
+
+# Handle 'ls' subcommand
+if args.subcommand == 'ls':
+    args.list_instances = True
+
+# Handle 'rm' subcommand
+if args.subcommand == 'rm':
+    if not hasattr(args, 'remove') or not args.remove:
+        args.remove = args.name
+
+# Handle 'select' subcommand
+if args.subcommand == 'select':
+    if not hasattr(args, 'select') or not args.select:
+        args.select = args.pattern
+
+# Handle 'exec' subcommand
+if args.subcommand == 'exec':
+    if not hasattr(args, 'exec_cmd') or not args.exec_cmd:
+        args.exec_cmd = args.command
+
 instances_outputs = {}
 
 def build_output(result):
@@ -226,9 +281,16 @@ class Acido(object):
         self.docker_username = os.getenv('DOCKER_USERNAME')
         self.docker_password = os.getenv('DOCKER_PASSWORD')
         
-
-        # Only try to create identity via Azure CLI if IDENTITY_CLIENT_ID is not already set
-        if not os.getenv('IDENTITY_CLIENT_ID', None) and not os.getenv('INSTANCE_NAME', None):
+        # Load managed identity from environment variables if provided
+        managed_identity_id = os.getenv('MANAGED_IDENTITY_ID')
+        managed_identity_client_id = os.getenv('MANAGED_IDENTITY_CLIENT_ID')
+        if managed_identity_id and managed_identity_client_id:
+            self.user_assigned = {
+                'id': managed_identity_id,
+                'clientId': managed_identity_client_id
+            }
+        # Only try to create identity via Azure CLI if managed identity env vars are not already set
+        elif not managed_identity_client_id and not os.getenv('INSTANCE_NAME', None):
             try:
                 az_identity_list = subprocess.check_output(f'az identity create --resource-group {self.rg} --name acido', shell=True)
                 az_identity_list = json.loads(az_identity_list)
@@ -399,10 +461,14 @@ class Acido(object):
         print(good(f"Selected all instances of group/s: [ {bold(' '.join(self.selected_instances))} ]"))
         return None if interactive else self.selected_instances
 
-    def fleet(self, fleet_name, instance_num=3, image_name=None, scan_cmd=None, input_file=None, wait=None, write_to_file=None, output_format='txt', interactive=True, quiet=False):
+    def fleet(self, fleet_name, instance_num=3, image_name=None, scan_cmd=None, input_file=None, wait=None, write_to_file=None, output_format='txt', interactive=True, quiet=False, pool=None):
         response = {}
         input_files = None
         
+        # Create pool if not provided
+        if pool is None:
+            pool = ThreadPoolShim(processes=30)
+        
         # Helper function to print only if not quiet
         def print_if_not_quiet(msg):
             if not quiet:
@@ -419,12 +485,14 @@ class Acido(object):
             for cg_n, ins_num in enumerate(instance_num_groups):
                 last_instance = len(ins_num)
                 env_vars = {
-                    'RG': self.rg,
+                    'AZURE_RESOURCE_GROUP': self.rg,
                     'IMAGE_REGISTRY_SERVER': self.image_registry_server,
                     'IMAGE_REGISTRY_USERNAME': self.image_registry_username,
                     'IMAGE_REGISTRY_PASSWORD': self.image_registry_password,
                     'STORAGE_ACCOUNT_NAME': self.storage_account,
-                    'IDENTITY_CLIENT_ID': self.user_assigned.get('clientId', None),
+                    'STORAGE_ACCOUNT_KEY': self.blob_manager.account_key,
+                    'MANAGED_IDENTITY_ID': self.user_assigned.get('id', None),
+                    'MANAGED_IDENTITY_CLIENT_ID': self.user_assigned.get('clientId', None),
                     'BLOB_CONNECTION': (
                         "DefaultEndpointsProtocol=https;"
                         f"AccountName={self.blob_manager.account_name};AccountKey={self.blob_manager.account_key};"
@@ -452,12 +520,14 @@ class Acido(object):
                 input_files = [self.save_input(f) for f in input_filenames]
 
             env_vars = {
-                    'RG': self.rg,
+                    'AZURE_RESOURCE_GROUP': self.rg,
                     'IMAGE_REGISTRY_SERVER': self.image_registry_server,
                     'IMAGE_REGISTRY_USERNAME': self.image_registry_username,
                     'IMAGE_REGISTRY_PASSWORD': self.image_registry_password,
                     'STORAGE_ACCOUNT_NAME': self.storage_account,
-                    'IDENTITY_CLIENT_ID': self.user_assigned.get('clientId', None),
+                    'STORAGE_ACCOUNT_KEY': self.blob_manager.account_key,
+                    'MANAGED_IDENTITY_ID': self.user_assigned.get('id', None),
+                    'MANAGED_IDENTITY_CLIENT_ID': self.user_assigned.get('clientId', None),
                     'BLOB_CONNECTION': (
                         "DefaultEndpointsProtocol=https;"
                         f"AccountName={self.blob_manager.account_name};AccountKey={self.blob_manager.account_key};"
@@ -506,7 +576,7 @@ class Acido(object):
             for cg, containers in response.items():
                 for cont in list(containers.keys()):
                     result = pool.apply_async(wait_command, 
-                                                (self.rg, cg, cont, wait), 
+                                                (self.rg, cg, cont, wait, self.instance_manager), 
                                                 callback=build_output)
                     results.append(result)
 
@@ -600,11 +670,16 @@ class Acido(object):
                 print(good(f'File loaded successfully.'))
         return input_file
 
-    def exec(self, command, max_retries=60, input_file: str = None, write_to_file: str =None):
+    def exec(self, command, max_retries=60, input_file: str = None, write_to_file: str =None, pool=None):
         global instances_outputs
         self.all_instances, self.instances_named = self.ls(interactive=False)
         results = []
         executed = False
+        
+        # Create pool if not provided
+        if pool is None:
+            pool = ThreadPoolShim(processes=30)
+        
         if not self.selected_instances:
             print(bad('You didn\'t select any containers to execute the command.'))
             return
@@ -678,7 +753,7 @@ class Acido(object):
         
         if not os.getenv('STORAGE_ACCOUNT_NAME', None):
             auth = ManagedAuthentication()
-            credential = auth.get_credential(Resources.BLOB)
+            credential = auth.get_credential()
             subscription = auth.extract_subscription(credential)
             client = StorageManagementClient(
                 credential,
@@ -1136,7 +1211,6 @@ def main():
     if args.download_input:
         acido.load_input(args.download_input, write_to_file=True)
     if args.fleet:
-        pool = ThreadPoolShim(processes=30)
         args.num_instances = int(args.num_instances) if args.num_instances else 1
         # Build full image URL from short name or keep full URL
         full_image_url = acido.build_image_url(args.image_name, args.image_tag)
@@ -1157,7 +1231,6 @@ def main():
     if args.select:
         acido.select(selection=args.select, interactive=bool(args.interactive))
     if args.exec_cmd:
-        pool = ThreadPoolShim(processes=30)
         acido.exec(
             command=args.exec_cmd, 
             max_retries=int(args.wait) if args.wait else 60, 
